function stats = computeBaconStats(decomp_results)  
% Compute additional statistics for Bacon decomposition  
% Written by Dr. Ralf ELsas, LMU SOM Munich
% - Version of 12/20/2024
% - Please cite when you use the program and write me an Email for all
%   errors or improvements

% Average treatment effect  
    ate = sum(decomp_results.estimate .* decomp_results.weight);  

    % Compute standard errors (assuming homoskedasticity)  
    var_estimate = var(decomp_results.estimate);  
    se = sqrt(var_estimate / size(decomp_results, 1));  

    % Compute confidence intervals  
    ci_lower = ate - 1.96 * se;  
    ci_upper = ate + 1.96 * se;  

    % Create output structure  
    stats = struct();  
    stats.ate = ate;  
    stats.se = se;  
    stats.ci_lower = ci_lower;  
    stats.ci_upper = ci_upper;  
    stats.n_comparisons = size(decomp_results, 1);  
end  